@@ -55,7 +55,7 @@ compute_pdedensity <- function(x) {
     Flag <- TRUE
   }
   
-  dens <- AdaptGauss::ParetoDensityEstimation(Data = x)
+  dens <- ParetoDensityEstimationV2(Data = x)
   
   # Density cannot be estiamted, set density to value equal 1
   if (Flag) {
